@@ -1,19 +1,27 @@
 # type: ignore
+# fmt: off
 
 from .cls import *
 from .func import *
 from .events import *
 from .hybrid import *
 from .iterable import *
-from .runners import *
 from .sleep import *
+from .thread import *
 
 
-__all__ = cls.__all__ + func.__all__ + events.__all__ + hybrid.__all__ + iterable.__all__ + runners.__all__
+__all__ = (
+    cls.__all__ +
+    func.__all__ +
+    events.__all__ +
+    hybrid.__all__ +
+    iterable.__all__ +
+    thread.__all__
+)
 
 
 __title__ = 'asyncify'
 __author__ = 'The Master'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2022-present The Master'
-__version__ = '1.4.4'
+__version__ = '2.0.0'
