@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import asyncio
 import functools
+import inspect
 import sys
 from typing import TYPE_CHECKING, Any, Callable, Dict, Set, Tuple, Type, TypeVar
 
@@ -20,9 +21,13 @@ else:
     P = TypeVar('P')
 
 
-_UNIX_ONLY_NAMES: Tuple[str, ...] = ('get_child_watcher', 'set_child_watcher')
-
-_VALID_NAMES: Tuple[str, ...] = ('get_event_loop', 'set_event_loop', 'new_event_loop', *_UNIX_ONLY_NAMES)
+_VALID_NAMES: Tuple[str, ...] = (
+    'get_event_loop',
+    'set_event_loop',
+    'new_event_loop',
+    'get_child_watcher',
+    'set_child_watcher',
+)
 
 
 class EventsEventLoopPolicy(asyncio.DefaultEventLoopPolicy):
@@ -52,13 +57,17 @@ class EventsEventLoopPolicy(asyncio.DefaultEventLoopPolicy):
         asyncio.run(main())  # prints 'New event loop being created.'
         # asyncio.run creates an event loop with `new_event_loop`
 
+    .. note::
+        :class:`asyncify.EventsEventLoopPolicy` inherits from `asyncio.DefaultEventLoopPolicy <https://docs.python.org/3/library/asyncio-policy.html#asyncio.DefaultEventLoopPolicy>`_
+        unless changed with :func:`asyncify.EventsEventLoopPolicy.change_base_policy`.
+
     .. warning::
         `asyncio.get_event_loop` won't call its event if there is a running and set event loop.
 
     .. versionadded:: 1.1
     """
 
-    _OLDS: Dict[str, Callable[..., Any]] = {}
+    _olds: Dict[str, Callable[..., Any]] = {}
 
     def __init__(self, *args: Any, **kwargs: Any):
         super().__init__(*args, **kwargs)
@@ -67,13 +76,14 @@ class EventsEventLoopPolicy(asyncio.DefaultEventLoopPolicy):
 
     @classmethod
     def _set_olds(cls) -> None:
-        cls._OLDS['get_event_loop'] = cls.get_event_loop
-        cls._OLDS['set_event_loop'] = cls.set_event_loop
-        cls._OLDS['new_event_loop'] = cls.new_event_loop
+        cls._olds['get_event_loop'] = cls.get_event_loop
+        cls._olds['set_event_loop'] = cls.set_event_loop
+        cls._olds['new_event_loop'] = cls.new_event_loop
 
-        if sys.platform != 'win32':
-            cls._OLDS['get_child_watcher'] = cls.get_child_watcher
-            cls._OLDS['set_child_watcher'] = cls.set_child_watcher
+        if hasattr(cls, 'get_child_watcher'):
+            cls._olds['get_child_watcher'] = cls.get_child_watcher
+        if hasattr(cls, 'set_child_watcher'):
+            cls._olds['set_child_watcher'] = cls.set_child_watcher
 
     def __repr__(self) -> str:
         return (
@@ -87,7 +97,7 @@ class EventsEventLoopPolicy(asyncio.DefaultEventLoopPolicy):
         Register a function to be called when an event loop policy method is called.
         The name of the functions should match the event loop policy method.
         The valid names are ``get_event_loop``, ``set_event_loop``, ``new_event_loop``,
-        ``get_child_watcher``, ``set_child_watcher``
+        ``get_child_watcher``, and ``set_child_watcher``.
 
         Example
         ---------
@@ -105,14 +115,11 @@ class EventsEventLoopPolicy(asyncio.DefaultEventLoopPolicy):
         TypeError
             `func` is not a callable.
         RuntimeError
-            The name either is invalid or is not supported on Windows.
+            The name either is invalid.
         """
-        if not isinstance(func, Callable):
+        if not TYPE_CHECKING and not inspect.isfunction(func):
             raise TypeError(f'Expected a callable, got {func.__class__.__name__!r}')
 
-        if sys.platform == 'win32' and func.__name__ in _UNIX_ONLY_NAMES:
-            raise RuntimeError(f'{func.__name__!r} is not supported on windows.')
-
         if func.__name__ not in _VALID_NAMES:
             raise RuntimeError(f'{func.__name__!r} is not a valid function name. {_VALID_NAMES} are valid.')
 
@@ -145,7 +152,7 @@ class EventsEventLoopPolicy(asyncio.DefaultEventLoopPolicy):
         if name not in self._registered_events:
             raise RuntimeError(f'{name!r} is not a registered event.')
 
-        setattr(self, name, self._OLDS[name])
+        setattr(self, name, self._olds[name])
         self._registered_events.remove(name)
 
     @classmethod
@@ -160,7 +167,7 @@ class EventsEventLoopPolicy(asyncio.DefaultEventLoopPolicy):
         ------------
         policy_cls: Type[:class:`asyncio.AbstractEventLoopPolicy`]
             This class must inherit from
-            `asyncio.AbstractEventLoopPolicy <https://docs.python.org/3/library/asyncio-policy.html#asyncio.AbstractEventLoopPolicy>`_
+            `asyncio.AbstractEventLoopPolicy <https://docs.python.org/3/library/asyncio-policy.html#asyncio.AbstractEventLoopPolicy>`_.
 
 
         This example uses `uvloop`.
